#!/bin/bash

#set -x

# nice value -20 (highest) to 19 (lowest) - default: 10
NICEVALUE=15

# enable Info for VDR Plugin BGPROCESS
svdrpsend.pl plug bgprocess | grep 'Plugin bgprocess' >/dev/null 2>&1 && ENABLE_BGPROC=1 

LOGFILE="/var/log/vdr/convert-record.log"
PJX_PATH="/opt/ProjectX"
JAVA="/usr/bin/java"

echo "---------- start $0 ----------------------" > $LOGFILE

usage() {
	echo "SYNTAX: $0 MPG|TS|DEMUX|MP4 in-dir out-dir (<MP4-METHOD>)" | tee -a $LOGFILE
	echo "OR: $0 VDR|TS|MPG|MP4 in-file out-dir (<MP4-METHOD>)" | tee -a $LOGFILE
	echo "wrong command syntax!" | tee -a $LOGFILE
	exit
}

echo "command: $*" | tee -a $LOGFILE
if [ ! -d "$3" ]
then	
    usage
fi

if [ "$ENABLE_BGPROC" = "1" ]; then
    TIMESTAMP=$(date +%s)
    svdrpsend.pl plug bgprocess process convert $TIMESTAMP 0 $1 >/dev/null 2>&1
fi

if [ -d "$2" ]; then
    CURRDIR=$(pwd)
    echo "switch to directory: $2" | tee -a $LOGFILE
    cd "$2"
    # ermittle Anzahl der Pfade (-1)
    VDR_FIELD_NUM=$(( $(echo $2|sed 's/ /-/g;s/\// /g'|wc -w) -1 ))
    echo "field counts: $VDR_FIELD_NUM" | tee -a $LOGFILE
    # gib die letzten 3 Pfade aus
    LAST3="$(echo "$2"|cut -f$VDR_FIELD_NUM- -d"/" |sed 's/[\\:\*\?"\<\>\|]//g;s/[%@]//g;s/#../_/g;s/Ü/Ue/g;s/ü/ue/g;s/Ö/Oe/g;s/ö/oe/g;s/Ä/Ae/g;s/ä/ae/g;s/ß/ss/g;s/\...\...\.rec//g;s/\.rec//g')"	
    echo "last 3 fields: $LAST3" | tee -a $LOGFILE
    if [ $VDR_FIELD_NUM -gt 2 ]; then
	ANAME="$(echo "$LAST3" | cut -d"/" -f 2)"
	# falls keine Name im zweitletzten Verzeichnis verfügbar, nimm eins davor
    	if [ "$ANAME" = "_" ]; then
	    ANAME="$(echo "$LAST3" | cut -d"/" -f 1)"
	fi
    elif [ $VDR_FIELD_NUM -eq 2 ]; then
	ANAME="$(echo "$LAST3" | cut -d"/" -f 2)"
    else
	echo "error: recording path contains only 2 sub paths" | tee -a $LOGFILE
	exit
    fi
    ADATE="$(echo "$LAST3" | cut -d"/" -f 3)"
    # entferne - und .
    ADATE="$(echo $ADATE | sed 's/[.-]//g')"
    ANAME="$(echo $ANAME | sed 's/[\.\!]//g')"
    OUTNAME="$ADATE-$ANAME"
    echo "recording name: $ANAME - recording date: $ADATE - whole name: $OUTNAME" | tee -a $LOGFILE
    if [ "$ENABLE_BGPROC" = "1" ]; then
	svdrpsend.pl plug bgprocess process convert $TIMESTAMP 1 $ANAME >/dev/null 2>&1
    fi
    if [ "$1" == "MPG" ]; then
	# falls Dateiname schon existiert
	if [ -e $3/$OUTNAME[pes].m2p ]; then
	    OUTNAME="$OUTNAME-$RANDOM"
	fi
    	# erzeuge MPG
	echo "erzeuge MPG..." | tee -a $LOGFILE
	# VDR TS oder PES Aufnahme
	if ( ls $2/*.ts ); then
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xmpg.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9][0-9][0-9].ts) | tee -a $LOGFILE
	else
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xmpg.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9].vdr) | tee -a $LOGFILE
	fi
    elif [ "$1" == "TS" ]; then
	# falls Dateiname schon existiert
	if [ -e $3/$OUTNAME.ts ]; then
	    OUTNAME="$OUTNAME-$RANDOM"
	fi
	# erzeuge TS
	echo "erzeuge TS..." | tee -a $LOGFILE
	# VDR TS oder PES Aufnahme
	if ( ls $2/*.ts ); then
	    nice -n $NICEVALUE cat `ls [0-9][0-9][0-9][0-9][0-9].ts` > $3/$OUTNAME.ts | tee -a $LOGFILE
	else
	    echo "pes"
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xts.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9].vdr) | tee -a $LOGFILE
	fi
    elif [ "$1" == "DEMUX" ]; then
	# demux 
	echo "starte demux..." | tee -a $LOGFILE
	# VDR TS oder PES Aufnahme
	if ( ls $2/*.ts ); then
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xdemux.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9][0-9][0-9].ts) | tee -a $LOGFILE
	else
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xdemux.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9].vdr) | tee -a $LOGFILE
	fi
    elif [ "$1" == "MP4" ]; then
	# erzeuge MP4
    	echo "erzeuge MP4..." | tee -a $LOGFILE
	# falls Dateiname schon existiert
	if [ -e $3/$OUTNAME[pes].m2p ]; then
	    OUTNAME="$OUTNAME-$RANDOM"
	fi
	# VDR TS oder PES Aufnahme
	if ( ls $2/*.ts ); then
	    TS_COUNT=`ls $2/*.ts -1 | wc -l`
	    echo "Anzahl der TS-Dateien: $TS_COUNT" | tee -a $LOGFILE
	    if [ $TS_COUNT -ge 2 ]; then
		nice -n $NICEVALUE cat `ls [0-9][0-9][0-9][0-9][0-9].ts` > $3/$OUTNAME.ts | tee -a $LOGFILE
		conv2mp4 $3/$OUTNAME.ts $3/$OUTNAME.mp4 $4 | tee -a $LOGFILE
		rm -f $3/$OUTNAME.ts
	    else
		conv2mp4 $2/00001.ts $3/$OUTNAME.mp4 $4 | tee -a $LOGFILE
	    fi
	else
	    nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xts.ini -out $3 -name "$OUTNAME" $(ls [0-9][0-9][0-9].vdr) | tee -a $LOGFILE
	    conv2mp4 $3/$OUTNAME.ts $3/$OUTNAME.mp4 $4 | tee -a $LOGFILE
	    rm -f $3/$OUTNAME.ts
	fi
    else
	usage
	exit
    fi
    echo "switch to directory: $CURRDIR" | tee -a $LOGFILE
    cd "$CURRDIR"

elif [ -f "$2" ]; then

    if [ "$1" == "VDR" ]; then
	# erzeuge VDR
	echo "erzeuge VDR..." | tee -a $LOGFILE
	nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xvdr.ini -out $3 "$2" | tee -a $LOGFILE
    elif [ "$1" == "TS" ]; then
	# erzeuge TS
	echo "erzeuge TS..." | tee -a $LOGFILE
	nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xts.ini -out $OUTTS "$2" | tee -a $LOGFILE
    elif [ "$1" == "MPG" ]; then
	# erzeuge MPG
	echo "erzeuge MPG..." >>$LOGFILE
	nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xmpg.ini -out $OUTMPG "$2" | tee -a $LOGFILE
    elif [ "$1" == "MP4" ]; then
	# erzeuge MP4
	echo "erzeuge MP4..." >>$LOGFILE
	#nice -n $NICEVALUE $JAVA -Djava.awt.headless=true -jar $PJX_PATH/ProjectX.jar -ini $PJX_PATH/Xmpg.ini -out $OUTMPG "$2" | tee -a $LOGFILE
	conv2mp4 "$2" $3/out.mp4 $4 | tee -a $LOGFILE
    else
	usage
    fi

else
    echo "third parameter must be a directory!" | tee -a $LOGFILE
    echo "wrong command syntax (third parameter)!" | tee -a $LOGFILE
fi

if [ "$ENABLE_BGPROC" = "1" ]; then
    svdrpsend.pl plug bgprocess process convert $TIMESTAMP 101 $1 >/dev/null 2>&1
fi

echo "--------- end $0 -------------------------" | tee -a $LOGFILE

# starte virtuellen X-Server
#/usr/bin/X11/Xvfb -screen 0 640x480x8 >/dev/null 2>&1 &
#sleep 1
#export DISPLAY="0:0"
#export LANG=de_DE@euro


# stoppe virtuellen X-Server
#PID=`/bin/pidof Xvfb`
#if [ x"$PID" != "x" ]; then
#    kill $PID
#fi
